// Sketch for the Benduino Sideshow v1.1
//
// https://www.printed-droid.com/kb/benduino-sideshow/
//
// This sketch randomizes sound and dome movement
// Pinout:
// IO16 - DF TX
// IO17 - DF RX
// IO18 - PWM Cytron
// IO19 - DIR Cytron
// IO12 - TX
// IO15 - RX
// IO35 - Encoder A
// IO34 - Encoder B
// IO22 - SCL
// IO21 - SDA
// IO2, 4, 13, 14, 23, 25, 26, 27, 32, 33 are usable via pins for free usage

#include "SoftwareSerial.h"
#include "DFRobotDFPlayerMini.h"

#define PWM_PIN 18
#define DIR_PIN 19

#define PWM_FREQUENCY 5000
#define PWM_CHANNEL 0
#define PWM_RESOLUTION 8

#define MOTOR_SPEED 128 // 50% speed
#define MOTOR_ACTIVE_TIME 400 //400ms then stop

#define DF_TX 17
#define DF_RX 16

SoftwareSerial mySoftwareSerial;

DFRobotDFPlayerMini myDFPlayer;

int next_sound=3000; // next sound played ms

int next_turn=5000; //next dome turn in ms
bool motor_dir = false;

void setup() {

  mySoftwareSerial.begin(9600, SWSERIAL_8N1,DF_RX, DF_TX, false);

  Serial.begin(115200);

  if (!myDFPlayer.begin(mySoftwareSerial)) {  //Use softwareSerial to communicate with mp3.
    Serial.println(F("Unable to begin:"));
    Serial.println(F("1.Please recheck the connection!"));
    Serial.println(F("2.Please insert the SD card!"));
    //while(true);
  }

  myDFPlayer.volume(10);  //Set volume value. From 0 to 30
  myDFPlayer.play(1);  //Play the first mp3

  ledcSetup(PWM_CHANNEL,PWM_FREQUENCY,PWM_RESOLUTION);
  ledcAttachPin(PWM_PIN, PWM_CHANNEL);

  pinMode(DIR_PIN, OUTPUT);
  digitalWrite(DIR_PIN, LOW);
  
}

void loop() {

  static unsigned long timer_mp3 = millis();
  static unsigned long timer_dome = millis();
  
  if (millis() - timer_mp3 > next_sound) {
    timer_mp3 = millis();
    int track = random(1,41); //uncomment to ranom mp3 every x second & next line
    myDFPlayer.play(track); //uncomment to random mp3 every x second & line before
    //myDFPlayer.next();  //uncomment to Play next mp3 every x second
    next_sound = random(3000,10001); //sound between 3 and 10 seconds
  }

  if (millis() - timer_dome > next_turn) {
    timer_dome = millis();

    if (motor_dir){
      digitalWrite(DIR_PIN, HIGH);
    } else {
      digitalWrite(DIR_PIN, LOW);
    }
    ledcWrite(PWM_CHANNEL, MOTOR_SPEED);
    delay(MOTOR_ACTIVE_TIME);
    ledcWrite(PWM_CHANNEL, 0);
    
    motor_dir = !motor_dir;
    next_turn = random(3000,10001); //dome-turn between 3 and 10 seconds
  }  
  
}
